#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-FIOh2I9hV7wHs1iXu5i7IF
key:                  tostring-0.2.1.1-FIOh2I9hV7wHs1iXu5i7IF
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  adfdd49237c435a7f1f30fba6f3c0dd7
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-FIOh2I9hV7wHs1iXu5i7IF
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-75BwTjwSfoc3sgy0QhC9q4
    text-2.0.2 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

